bayespy.nodes.CategoricalMarkovChain
====================================

.. currentmodule:: bayespy.nodes

.. autoclass:: CategoricalMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalMarkovChain.__init__
      ~CategoricalMarkovChain.add_plate_axis
      ~CategoricalMarkovChain.broadcasting_multiplier
      ~CategoricalMarkovChain.delete
      ~CategoricalMarkovChain.get_gradient
      ~CategoricalMarkovChain.get_mask
      ~CategoricalMarkovChain.get_moments
      ~CategoricalMarkovChain.get_parameters
      ~CategoricalMarkovChain.get_riemannian_gradient
      ~CategoricalMarkovChain.get_shape
      ~CategoricalMarkovChain.has_plotter
      ~CategoricalMarkovChain.initialize_from_parameters
      ~CategoricalMarkovChain.initialize_from_prior
      ~CategoricalMarkovChain.initialize_from_random
      ~CategoricalMarkovChain.initialize_from_value
      ~CategoricalMarkovChain.load
      ~CategoricalMarkovChain.logpdf
      ~CategoricalMarkovChain.lower_bound_contribution
      ~CategoricalMarkovChain.lowerbound
      ~CategoricalMarkovChain.move_plates
      ~CategoricalMarkovChain.observe
      ~CategoricalMarkovChain.pdf
      ~CategoricalMarkovChain.plot
      ~CategoricalMarkovChain.random
      ~CategoricalMarkovChain.save
      ~CategoricalMarkovChain.set_parameters
      ~CategoricalMarkovChain.set_plotter
      ~CategoricalMarkovChain.show
      ~CategoricalMarkovChain.unobserve
      ~CategoricalMarkovChain.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalMarkovChain.dims
      ~CategoricalMarkovChain.plates
      ~CategoricalMarkovChain.plates_multiplier
   
   